==> cppad_2014.00.00.3.orig.tar.gz: cppad-20140000.3/doc/_wishlist_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'wishlist.xml'
];
var list_down2 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'library.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down1 = [
'faq.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'bugs.xml',
'wishlist.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'license.xml'
];
var list_current0 = [
'wishlist.xml#Adolc',
'wishlist.xml#Atan2',
'wishlist.xml#BenderQuad',
'wishlist.xml#Checkpointing',
'wishlist.xml#Conditional Expressions',
'wishlist.xml#Conditional Expressions.Nesting',
'wishlist.xml#Conditional Expressions.Sparsity',
'wishlist.xml#Forward Mode Recomputation',
'wishlist.xml#Iterator Interface',
'wishlist.xml#Library',
'wishlist.xml#Multiple Argument Forward',
'wishlist.xml#Numeric Limits',
'wishlist.xml#Operation Sequence',
'wishlist.xml#Optimization',
'wishlist.xml#Optimization.Expression Hashing',
'wishlist.xml#Optimization.Variable Pairs',
'wishlist.xml#Preprocessor Symbols',
'wishlist.xml#Software Guidelines',
'wishlist.xml#Software Guidelines.Boost',
'wishlist.xml#Tracing'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad_2015.00.00.2.orig.tar.gz: cppad-20150000.2/doc/_wishlist_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'wishlist.xml'
];
var list_down2 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'library.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down1 = [
'faq.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'bugs.xml',
'wishlist.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'license.xml'
];
var list_current0 = [
'wishlist.xml#Adolc',
'wishlist.xml#Atan2',
'wishlist.xml#BenderQuad',
'wishlist.xml#Checkpointing',
'wishlist.xml#Conditional Expressions',
'wishlist.xml#Conditional Expressions.Nesting',
'wishlist.xml#Conditional Expressions.Sparsity',
'wishlist.xml#Forward Mode Recomputation',
'wishlist.xml#Iterator Interface',
'wishlist.xml#Library',
'wishlist.xml#Multiple Directions',
'wishlist.xml#Numeric Limits',
'wishlist.xml#Operation Sequence',
'wishlist.xml#Optimization',
'wishlist.xml#Optimization.Expression Hashing',
'wishlist.xml#Optimization.Variable Pairs',
'wishlist.xml#Preprocessor Symbols',
'wishlist.xml#Software Guidelines',
'wishlist.xml#Software Guidelines.Boost',
'wishlist.xml#Tracing'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
